netapp_ontap.models.software_mcc API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.software_mcc`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SoftwareMccSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SoftwareMcc object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `elapsed_duration: Size GET`

    Elapsed duration of update time (in seconds) of MetroCluster.

    Example: 2140

  `estimated_duration: Size GET`

    Estimated duration of update time (in seconds) of MetroCluster.

    Example: 3480

  `name: str GET`

    Name of the site in MetroCluster.

    Example: cluster_A

  `state: str GET`

    Upgrade state of MetroCluster.

    Valid choices:

    - in_progress
    - waiting
    - paused_by_user
    - paused_on_error
    - completed
    - canceled
    - failed
    - pause_pending
    - cancel_pending